@@ -146,7 +146,7 @@ See <a href="http://wiki.typo3.org/index.php/TYPO3_3.8.1" target="_blank">wiki.t
 
 		if ($GLOBALS['TSFE']->type && $GLOBALS['TSFE']->config['config']['frameReloadIfNotInFrameset'])	{
 			$tdlLD = $GLOBALS['TSFE']->tmpl->linkData($GLOBALS['TSFE']->page,'_top',$GLOBALS['TSFE']->no_cache,'');
-			$GLOBALS['TSFE']->JSCode = 'if(!parent.'.trim($GLOBALS['TSFE']->sPre).' && !parent.view_frame) top.location.href="'.$GLOBALS['TSFE']->baseUrlWrap($tdlLD['totalURL']).'"';
+			$GLOBALS['TSFE']->additionalJavaScript['JSCode'] .= 'if(!parent.'.trim($GLOBALS['TSFE']->sPre).' && !parent.view_frame) top.location.href="'.$GLOBALS['TSFE']->baseUrlWrap($tdlLD['totalURL']).'"';
 		}
 		$GLOBALS['TSFE']->compensateFieldWidth = ''.$GLOBALS['TSFE']->config['config']['compensateFieldWidth'];
 		$GLOBALS['TSFE']->lockFilePath = ''.$GLOBALS['TSFE']->config['config']['lockFilePath'];
@@ -506,6 +506,9 @@ See <a href="http://wiki.typo3.org/index.php/TYPO3_3.8.1" target="_blank">wiki.t
 					finfo_close($finfo);
 					$pageRenderer->setIconMimeType($iconMimeType);
 				}
+			} elseif (function_exists('mime_content_type')) {
+				$iconMimeType = ' type="' . mime_content_type(PATH_site . $favIcon) . '"';
+				$pageRenderer->setIconMimeType($iconMimeType);
 			}
 			$pageRenderer->setFavIcon(t3lib_div::getIndpEnv('TYPO3_SITE_URL') . $favIcon);
 
@@ -1208,4 +1211,4 @@ class FE_loadDBGroup extends t3lib_loadDBGroup {
 	var $fromTC = 0;	// Means that everything is returned instead of only uid and label-field
 }
 
-?>
+?>
\ No newline at end of file
