@@ -298,7 +298,7 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 					// Get the list of files from the field
 				$field = (trim($conf['field']) ? trim($conf['field']) : 'media');
 				$fileList = $this->cObj->data[$field];
-				t3lib_div::loadTCA('tt_content');
+				$GLOBALS['TSFE']->includeTCA();
 				$path = 'uploads/media/';
 				if (is_array($GLOBALS['TCA']['tt_content']['columns'][$field]) && !empty($GLOBALS['TCA']['tt_content']['columns'][$field]['config']['uploadfolder'])) {
 					// in TCA-Array folders are saved without trailing slash, so $path.$fileName won't work
@@ -538,7 +538,9 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 			// Use the calculated information (amount of images, if global caption is wanted) to choose a different rendering method for the images-block
 		$GLOBALS['TSFE']->register['imageCount'] = $imgCount;
 		$GLOBALS['TSFE']->register['renderGlobalCaption'] = $renderGlobalCaption;
-		$fallbackRenderMethod = $this->cObj->cObjGetSingle($conf['fallbackRendering'], $conf['fallbackRendering.']);
+		if ($conf['fallbackRendering']) {
+			$fallbackRenderMethod = $this->cObj->cObjGetSingle($conf['fallbackRendering'], $conf['fallbackRendering.']);
+		}
 		if ($fallbackRenderMethod && is_array($conf['rendering.'][$fallbackRenderMethod . '.']))	{
 			$conf = $this->cObj->joinTSarrays($conf, $conf['rendering.'][$fallbackRenderMethod . '.']);
 		}
